@@ -1,10 +1,11 @@
 """Base action for bronotes."""
 import os
+from bronotes.config import cfg
+from fuzzy_match import match
 from datetime import datetime
 from git import Repo
 from git.exc import InvalidGitRepositoryError
 from git.exc import GitCommandError
-from pathlib import Path
 from abc import ABC, abstractmethod
 
 
@@ -29,9 +30,12 @@ class BronoteAction(ABC):
         """Allow flags for the action."""
         pass
 
-    def __init__(self, cfg):
+    def __init__(self, config=False):
         """Construct the action."""
-        self.cfg = cfg
+        if config:
+            self.cfg = config
+        else:
+            self.cfg = cfg
 
     @abstractmethod
     def init(self):
@@ -39,7 +43,7 @@ class BronoteAction(ABC):
         pass
 
     @abstractmethod
-    def process(self):
+    def process(self, **kwargs):
         """Process the action."""
         pass
 
@@ -62,23 +66,25 @@ class BronoteAction(ABC):
             except AttributeError:
                 setattr(self, argument, None)
 
-    def add_arguments(self, subparser):
+    @classmethod
+    def add_arguments(cls, subparser):
         """Add an actions arguments to a subparser."""
-        for argument in self.arguments.keys():
-            argdict = self.arguments[argument]
+        for argument in cls.arguments.keys():
+            argdict = cls.arguments[argument]
 
             subparser.add_argument(
                 argument,
                 help=argdict['help'],
                 nargs=argdict['nargs']
             ).complete = {
-                "zsh": f"_files -W {self.cfg.notes_dir}",
+                "zsh": f"_files -W {cfg.notes_dir}",
             }
 
-    def add_flags(self, subparser):
+    @classmethod
+    def add_flags(cls, subparser):
         """Add an actions flags to a subparser."""
-        for flag in self.flags.keys():
-            flagdict = self.flags[flag]
+        for flag in cls.flags.keys():
+            flagdict = cls.flags[flag]
 
             subparser.add_argument(
                 flagdict['short'],
@@ -87,14 +93,15 @@ class BronoteAction(ABC):
                 help=flagdict['help']
             )
 
-    def add_subparser(self, subparsers):
+    @classmethod
+    def add_subparser(cls, subparsers):
         """Add a subparser based on a actions arguments and flags."""
         subparser = subparsers.add_parser(
-            self.action, help=self.__doc__)
+            cls.action, help=cls.__doc__)
 
-        subparser.set_defaults(action=self)
-        self.add_arguments(subparser)
-        self.add_flags(subparser)
+        subparser.set_defaults(action=cls)
+        cls.add_arguments(subparser)
+        cls.add_flags(subparser)
 
     def sync(self):
         """Sync with git."""
@@ -136,11 +143,22 @@ Auto-syncing can be enable through the set action.'
         git.push('origin', 'master')
 
     def find_note(self, filename):
-        """Find first occurance of a note traversing from the base folder."""
-        for node in os.walk(self.cfg.notes_dir):
-            (basepath, dirs, files) = node
+        """Find best match of a note traversing from the base folder.
+
+        Excludes .git directory.
+        """
+        choices = {}
+        exclude_dirs = ['.git']
+
+        for root, dirs, files in os.walk(self.cfg.notes_dir):
+            dirs[:] = [d for d in dirs if d not in exclude_dirs]
 
             for file in files:
-                if filename in file:
-                    return Path(f"{basepath}/{file}")
-        return False
+                choices[file] = f"{root}/{file}"
+
+        (result, match_index) = match.extractOne(
+            filename,
+            [i for i in choices.keys()]
+        )
+
+        return choices[result]
